<?php
session_start();

// Verificar si el usuario está autenticado
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Verificar si se especificó un ID de chat
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: dashboard.php');
    exit();
}

// Datos del usuario actual
$user_id = $_SESSION['user_id'];
$current_user_name = $_SESSION['name'];
$current_user_phone = $_SESSION['phone'];

// ID del otro usuario
$other_user_id = intval($_GET['id']);

// Conexión a la base de datos
require_once 'config.php';

// Obtener información del otro usuario
$user_query = "SELECT u.id, u.name, u.phone, us.status, us.last_activity 
               FROM users u 
               LEFT JOIN user_status us ON u.id = us.user_id 
               WHERE u.id = ?";
$user_stmt = $conn->prepare($user_query);
$user_stmt->bind_param("i", $other_user_id);
$user_stmt->execute();
$user_result = $user_stmt->get_result();

if ($user_result->num_rows === 0) {
    header('Location: dashboard.php');
    exit();
}

$other_user = $user_result->fetch_assoc();
$other_user_name = $other_user['name'];
$other_user_phone = $other_user['phone'];
$other_user_status = $other_user['status'] ?: 'offline';
$other_user_last_activity = $other_user['last_activity'];

// Obtener historial de mensajes
$messages_query = "
    SELECT 
        id, sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type,
        timestamp, `read`, delivered
    FROM 
        messages
    WHERE 
        (sender_id = ? AND receiver_id = ? AND deleted = 0) OR (sender_id = ? AND receiver_id = ? AND deleted = 0)
    ORDER BY 
        timestamp ASC
";
$messages_stmt = $conn->prepare($messages_query);
$messages_stmt->bind_param("iiii", $user_id, $other_user_id, $other_user_id, $user_id);
$messages_stmt->execute();
$messages_result = $messages_stmt->get_result();
$messages = [];
while ($row = $messages_result->fetch_assoc()) {
    $messages[] = $row;
}

// Marcar mensajes como leídos
$update_query = "
    UPDATE messages 
    SET `read` = 1 
    WHERE sender_id = ? AND receiver_id = ? AND `read` = 0
";
$update_stmt = $conn->prepare($update_query);
$update_stmt->bind_param("ii", $other_user_id, $user_id);
$update_stmt->execute();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FlyChat - Chat con <?php echo htmlspecialchars($other_user_name); ?></title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/emoji-mart@latest/css/emoji-mart.css">
    <style>
        .blue-gradient {
            background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%);
        }
        .message-out {
            background-color: #dcf8c6;
            align-self: flex-end;
            border-radius: 0.75rem 0 0.75rem 0.75rem;
        }
        .message-in {
            background-color: white;
            align-self: flex-start;
            border-radius: 0 0.75rem 0.75rem 0.75rem;
        }
        .typing-indicator {
            display: inline-block;
        }
        .typing-indicator span {
            display: inline-block;
            width: 8px;
            height: 8px;
            background-color: #999;
            border-radius: 50%;
            margin-right: 3px;
            animation: typing 1.4s infinite ease-in-out;
        }
        .typing-indicator span:nth-child(1) {
            animation-delay: 0s;
        }
        .typing-indicator span:nth-child(2) {
            animation-delay: 0.2s;
        }
        .typing-indicator span:nth-child(3) {
            animation-delay: 0.4s;
            margin-right: 0;
        }
        @keyframes typing {
            0% { transform: scale(1); }
            50% { transform: scale(1.5); }
            100% { transform: scale(1); }
        }
        /* Estilos mejorados para el emoji picker */
        .emoji-mart {
            position: fixed !important; /* Cambiado de absolute a fixed */
            bottom: 80px;
            left: 50%;
            transform: translateX(-50%); /* Centrado horizontal */
            z-index: 100;
            max-width: 90%; /* Limitar ancho en pantallas pequeñas */
            width: 338px !important; /* Ancho fijo estándar de emoji-mart */
        }
        @media (max-width: 400px) {
            .emoji-mart {
                width: 280px !important; /* Más pequeño en móviles */
                font-size: 12px; /* Texto más pequeño */
            }
        }
        .emoji-picker-trigger {
            cursor: pointer;
        }
        .emoji-picker-trigger:hover {
            color: #0088cc;
        }
        .message-image {
            max-width: 240px;
            max-height: 240px;
            border-radius: 8px;
            cursor: pointer;
        }
        .message-video {
            max-width: 240px;
            max-height: 320px;
            border-radius: 8px;
        }
        .message-file {
            display: flex;
            align-items: center;
            padding: 10px;
            border-radius: 8px;
            background-color: rgba(0,0,0,0.05);
        }
        .file-icon {
            font-size: 24px;
            margin-right: 10px;
        }
        .file-info {
            display: flex;
            flex-direction: column;
        }
        .file-name {
            font-weight: 500;
            margin-bottom: 4px;
            word-break: break-all;
        }
        .file-size {
            font-size: 12px;
            color: #666;
        }
        .message-status {
            display: flex;
            align-items: center;
            font-size: 12px;
            color: #999;
            margin-left: 5px;
        }
        .status-icon {
            margin-right: 3px;
        }
        /* Estilos para llamadas */
        .call-overlay {
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(0,0,0,0.8);
            z-index: 1000;
            display: none; /* Inicialmente oculto */
            flex-direction: column;
            justify-content: center;
            align-items: center;
            color: white;
        }
        .call-overlay.active {
            display: flex; /* Se mostrará con active */
        }
        .call-header {
            margin-bottom: 20px;
            text-align: center;
        }
        .call-avatar {
            width: 100px;
            height: 100px;
            border-radius: 50%;
            background-color: #0088cc;
            display: flex;
            justify-content: center;
            align-items: center;
            font-size: 48px;
            margin: 0 auto 20px;
        }
        .call-name {
            font-size: 24px;
            margin-bottom: 5px;
        }
        .call-status {
            font-size: 16px;
            opacity: 0.8;
        }
        .call-video-container {
            width: 100%;
            max-width: 800px;
            display: flex;
            flex-direction: column;
            margin: 0 auto;
        }
        .remote-video {
            width: 100%;
            height: 100%;
            background-color: #222;
            border-radius: 10px;
            margin-bottom: 10px;
        }
        .local-video {
            position: absolute;
            width: 150px;
            height: 200px;
            right: 20px;
            top: 100px;
            background-color: #333;
            border-radius: 10px;
            border: 2px solid white;
        }
        .call-controls {
            display: flex;
            justify-content: center;
            margin-top: 20px;
        }
        .call-btn {
            width: 60px;
            height: 60px;
            border-radius: 50%;
            display: flex;
            justify-content: center;
            align-items: center;
            margin: 0 10px;
            cursor: pointer;
        }
        .accept-btn {
            background-color: #4CAF50;
        }
        .reject-btn {
            background-color: #F44336;
        }
        .video-btn {
            background-color: #2196F3;
        }
        .mic-btn {
            background-color: #9E9E9E;
        }
        /* Reemplazo completo de clases de modal */
        .modal {
            display: none !important; /* Inicialmente oculto con !important */
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(0,0,0,0.7);
            z-index: 200;
            justify-content: center;
            align-items: center;
        }
        .modal.active {
            display: flex !important; /* Forzar mostrar con !important */
        }
        .modal-content {
            background-color: white;
            border-radius: 10px;
            max-width: 90%;
        }
        .image-preview {
            max-width: 100%;
            max-height: 80vh;
            border-radius: 10px;
        }
    </style>
</head>
<body class="bg-gray-100 h-screen flex flex-col">
    <!-- Barra superior con información del chat -->
    <header class="blue-gradient text-white p-4 flex items-center">
        <a href="dashboard.php" class="mr-3">
            <i class="fas fa-arrow-left"></i>
        </a>
        <div class="w-10 h-10 rounded-full bg-blue-300 flex items-center justify-center text-blue-800 font-bold mr-3">
            <span><?php echo strtoupper(substr($other_user_name, 0, 1)); ?></span>
        </div>
        <div class="flex-1">
            <h1 class="font-bold"><?php echo htmlspecialchars($other_user_name); ?></h1>
            <p class="text-xs text-blue-100" id="status-text"><?php echo $other_user_status; ?></p>
        </div>
        <div class="flex">
            <button class="p-2 mx-1" id="audio-call-btn">
                <i class="fas fa-phone"></i>
            </button>
            <button class="p-2 mx-1" id="video-call-btn">
                <i class="fas fa-video"></i>
            </button>
            <button class="p-2 mx-1" id="menu-btn">
                <i class="fas fa-ellipsis-v"></i>
            </button>
        </div>
    </header>
    
    <!-- Menú lateral (oculto por defecto) -->
    <div id="side-menu" class="fixed inset-0 bg-black bg-opacity-50 z-50 hidden">
        <div class="w-64 h-full bg-white flex flex-col">
            <div class="blue-gradient p-4 text-white flex items-center">
                <div class="w-12 h-12 rounded-full bg-blue-300 flex items-center justify-center text-blue-800 font-bold mr-3">
                    <span><?php echo strtoupper(substr($current_user_name, 0, 1)); ?></span>
                </div>
                <div>
                    <h2 class="font-bold"><?php echo htmlspecialchars($current_user_name); ?></h2>
                    <p class="text-sm text-blue-100"><?php echo htmlspecialchars($current_user_phone); ?></p>
                </div>
            </div>
            <div class="flex-1 p-2">
                <a href="dashboard.php" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-user-friends mr-2"></i> Contactos
                </a>
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-cog mr-2"></i> Configuración
                </a>
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-question-circle mr-2"></i> Ayuda
                </a>
            </div>
            <div class="p-3 border-t">
                <a href="logout.php" class="block w-full py-2 px-4 text-red-500 rounded hover:bg-red-50 text-left">
                    <i class="fas fa-sign-out-alt mr-2"></i> Cerrar sesión
                </a>
            </div>
        </div>
        <div class="flex-1" id="menu-overlay"></div>
    </div>
    
    <!-- Área de chat -->
    <div class="flex-1 overflow-y-auto bg-gray-200 p-4" id="chat-messages">
        <!-- Los mensajes se cargarán aquí con JavaScript -->
    </div>
    
    <!-- Indicador de "escribiendo" -->
    <div id="typing-indicator" class="px-4 py-2 bg-gray-200 hidden">
        <div class="text-gray-500 text-sm">
            <?php echo htmlspecialchars($other_user_name); ?> está escribiendo
            <div class="typing-indicator">
                <span></span>
                <span></span>
                <span></span>
            </div>
        </div>
    </div>
    
    <!-- Área de entrada de mensaje -->
    <div class="bg-gray-100 p-3 border-t flex items-center">
        <div class="flex-1 bg-white rounded-full shadow-sm flex items-center px-3">
            <button class="text-gray-500 p-2 emoji-picker-trigger" id="emoji-btn">
                <i class="far fa-smile"></i>
            </button>
            <input type="text" id="message-input" placeholder="Escribe un mensaje..." 
                   class="w-full py-2 px-2 focus:outline-none">
            <div id="emoji-picker-container" class="hidden"></div>
            <label for="file-input" class="text-gray-500 p-2 cursor-pointer">
                <i class="fas fa-paperclip"></i>
            </label>
            <input type="file" id="file-input" class="hidden" accept="image/*,video/*,application/pdf,application/msword,application/vnd.openxmlformats-officedocument.wordprocessingml.document,text/plain">
        </div>
        <button id="send-btn" class="ml-2 w-10 h-10 rounded-full blue-gradient text-white flex items-center justify-center">
            <i class="fas fa-paper-plane"></i>
        </button>
    </div>
    
    <!-- Contenedor de imagen modal (oculto por defecto) -->
    <div id="image-modal" class="modal">
        <div class="modal-content">
            <img id="modal-image" src="" alt="Preview" class="image-preview">
        </div>
    </div>
    
    <!-- Contenedor de llamada (oculto por defecto) -->
    <div id="call-container" class="call-overlay">
        <div id="incoming-call" class="hidden">
            <div class="call-header">
                <div class="call-avatar"><?php echo strtoupper(substr($other_user_name, 0, 1)); ?></div>
                <div class="call-name"><?php echo htmlspecialchars($other_user_name); ?></div>
                <div class="call-status" id="call-status-text">Llamada entrante...</div>
            </div>
            <div class="call-controls">
                <button id="reject-call" class="call-btn reject-btn">
                    <i class="fas fa-phone-slash fa-lg"></i>
                </button>
                <button id="accept-call" class="call-btn accept-btn">
                    <i class="fas fa-phone fa-lg"></i>
                </button>
            </div>
        </div>
        
        <div id="outgoing-call" class="hidden">
            <div class="call-header">
                <div class="call-avatar"><?php echo strtoupper(substr($other_user_name, 0, 1)); ?></div>
                <div class="call-name"><?php echo htmlspecialchars($other_user_name); ?></div>
                <div class="call-status" id="outgoing-status-text">Llamando...</div>
            </div>
            <div class="call-controls">
                <button id="cancel-call" class="call-btn reject-btn">
                    <i class="fas fa-phone-slash fa-lg"></i>
                </button>
            </div>
        </div>
        
        <div id="ongoing-call" class="hidden">
            <div class="call-video-container">
                <video id="remote-video" class="remote-video" autoplay></video>
                <video id="local-video" class="local-video" autoplay muted></video>
            </div>
            <div class="call-controls">
                <button id="toggle-mic" class="call-btn mic-btn">
                    <i class="fas fa-microphone fa-lg"></i>
                </button>
                <button id="toggle-video" class="call-btn video-btn">
                    <i class="fas fa-video fa-lg"></i>
                </button>
                <button id="end-call" class="call-btn reject-btn">
                    <i class="fas fa-phone-slash fa-lg"></i>
                </button>
            </div>
        </div>
    </div>
    
    <!-- Scripts JS -->
    <script src="https://cdn.jsdelivr.net/npm/emoji-mart@latest/dist/browser.js"></script>
    <script>
        // Registro de depuración para encontrar elementos modales
        console.log('Iniciando script...');
        
        // Intentar detectar elementos modales al cargar la página
        window.addEventListener('DOMContentLoaded', function() {
            console.log('DOM cargado, buscando modales...');
            const allElements = document.querySelectorAll('*');
            const modalCandidates = [];
            
            for (let i = 0; i < allElements.length; i++) {
                const el = allElements[i];
                const style = window.getComputedStyle(el);
                
                if (style.position === 'fixed' && (
                    style.zIndex > 50 || 
                    style.backgroundColor.includes('rgba') ||
                    style.display !== 'none'
                )) {
                    modalCandidates.push({
                        element: el,
                        id: el.id || 'sin-id',
                        zIndex: style.zIndex,
                        position: style.position,
                        display: style.display,
                        bgColor: style.backgroundColor
                    });
                }
            }
            
            console.log('Posibles elementos modales encontrados:', modalCandidates);
            
            // Forzar ocultar todos los elementos modales conocidos
            const imageModal = document.getElementById('image-modal');
            const callContainer = document.getElementById('call-container');
            const sideMenu = document.getElementById('side-menu');
            
            if (imageModal) {
                console.log('Ocultando modal de imagen...');
                imageModal.style.display = 'none';
                imageModal.style.visibility = 'hidden';
                imageModal.style.opacity = '0';
            }
            
            if (callContainer) {
                console.log('Ocultando contenedor de llamada...');
                callContainer.style.display = 'none';
                callContainer.style.visibility = 'hidden';
                callContainer.style.opacity = '0';
            }
            
            if (sideMenu) {
                console.log('Ocultando menú lateral...');
                sideMenu.classList.add('hidden');
            }
            
            // También ocultar cualquier otro elemento que parezca un modal
            modalCandidates.forEach(candidate => {
                if (candidate.id !== 'image-modal' && candidate.id !== 'call-container' && candidate.id !== 'side-menu') {
                    console.log('Ocultando candidato a modal:', candidate.id);
                    candidate.element.style.display = 'none';
                    candidate.element.style.visibility = 'hidden';
                    candidate.element.style.opacity = '0';
                }
            });
        });
    
        // Variables globales
        const currentUser = {
            id: <?php echo $user_id; ?>,
            name: "<?php echo addslashes($current_user_name); ?>",
            phone: "<?php echo addslashes($current_user_phone); ?>"
        };
        
        const otherUser = {
            id: <?php echo $other_user_id; ?>,
            name: "<?php echo addslashes($other_user_name); ?>",
            phone: "<?php echo addslashes($other_user_phone); ?>",
            status: "<?php echo $other_user_status; ?>"
        };
        
        // Configura la URL del servidor WebSocket - cambia esta línea si usas un VPS
        // Para localhost:
        const WEBSOCKET_URL = 'ws://localhost:8080';
        // Para un servidor remoto (VPS):
        // const WEBSOCKET_URL = 'ws://tu-dominio-o-ip:8080';
        
        let typingTimeout = null;
        let socket = null;
        let isConnected = false;
        let reconnectAttempts = 0;
        const MAX_RECONNECT_ATTEMPTS = 5;
        
        // Variables para llamadas
        let currentCall = null;
        let localStream = null;
        let peerConnection = null;
        let isAudioEnabled = true;
        let isVideoEnabled = true;
        let heartbeatInterval = null;
        
        // Configuración de WebRTC
        const rtcConfig = {
            iceServers: [
                { urls: 'stun:stun.l.google.com:19302' },
                { urls: 'stun:stun1.l.google.com:19302' }
            ]
        };
        
        // Cargar mensajes iniciales
        const initialMessages = <?php echo json_encode($messages); ?>;
        
        // Función para formatear fecha/hora
        function formatTimestamp(timestamp) {
            const date = new Date(timestamp);
            return date.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' });
        }
        
        // Función para formatear tamaño de archivo
        function formatFileSize(bytes) {
            if (bytes < 1024) return bytes + ' B';
            if (bytes < 1024 * 1024) return Math.round(bytes / 1024) + ' KB';
            return Math.round(bytes / (1024 * 1024) * 10) / 10 + ' MB';
        }
        
        // Función para crear elemento de mensaje
        function createMessageElement(message, isOutgoing) {
            const messageDiv = document.createElement('div');
            messageDiv.className = `max-w-[80%] p-3 mb-2 shadow-sm ${isOutgoing ? 'message-out self-end' : 'message-in self-start'}`;
            messageDiv.setAttribute('data-message-id', message.id);
            
            let contentDiv;
            
            // Crear contenido según el tipo de mensaje
            switch(message.type) {
                case 'image':
                    contentDiv = document.createElement('div');
                    const img = document.createElement('img');
                    img.src = message.file_url;
                    img.alt = 'Imagen';
                    img.className = 'message-image';
                    img.onclick = () => showImageModal(message.file_url);
                    contentDiv.appendChild(img);
                    
                    if (message.message) {
                        const caption = document.createElement('div');
                        caption.className = 'text-sm mt-1';
                        caption.textContent = message.message;
                        contentDiv.appendChild(caption);
                    }
                    break;
                    
                case 'video':
                    contentDiv = document.createElement('div');
                    const video = document.createElement('video');
                    video.src = message.file_url;
                    video.className = 'message-video';
                    video.controls = true;
                    contentDiv.appendChild(video);
                    
                    if (message.message) {
                        const caption = document.createElement('div');
                        caption.className = 'text-sm mt-1';
                        caption.textContent = message.message;
                        contentDiv.appendChild(caption);
                    }
                    break;
                    
                case 'file':
                    contentDiv = document.createElement('div');
                    const fileLink = document.createElement('a');
                    fileLink.href = message.file_url;
                    fileLink.target = '_blank';
                    fileLink.className = 'message-file';
                    
                    const iconClass = getFileIconClass(message.file_name);
                    const icon = document.createElement('div');
                    icon.className = `file-icon ${iconClass}`;
                    
                    const fileInfo = document.createElement('div');
                    fileInfo.className = 'file-info';
                    
                    const fileName = document.createElement('div');
                    fileName.className = 'file-name';
                    fileName.textContent = message.file_name;
                    
                    const fileSize = document.createElement('div');
                    fileSize.className = 'file-size';
                    fileSize.textContent = formatFileSize(message.file_size);
                    
                    fileInfo.appendChild(fileName);
                    fileInfo.appendChild(fileSize);
                    
                    fileLink.appendChild(icon);
                    fileLink.appendChild(fileInfo);
                    contentDiv.appendChild(fileLink);
                    break;
                    
                default: // texto
                    contentDiv = document.createElement('div');
                    contentDiv.className = 'text-sm';
                    contentDiv.innerHTML = formatMessageWithEmojis(message.message);
            }
            
            // Agregar contenido al mensaje
            messageDiv.appendChild(contentDiv);
            
            // Agregar footer con hora y estado
            const footerDiv = document.createElement('div');
            footerDiv.className = 'flex justify-end items-center mt-1';
            
            const timeSpan = document.createElement('span');
            timeSpan.className = 'text-xs text-gray-500';
            timeSpan.textContent = formatTimestamp(message.timestamp);
            
            footerDiv.appendChild(timeSpan);
            
            // Agregar indicadores de estado (enviado, entregado, leído) solo para mensajes salientes
            if (isOutgoing) {
                const statusDiv = document.createElement('div');
                statusDiv.className = 'message-status ml-1';
                
                let statusIcon = '';
                if (message.read) {
                    statusIcon = '<i class="fas fa-check-double text-blue-500 status-icon"></i>';
                } else if (message.delivered) {
                    statusIcon = '<i class="fas fa-check-double text-gray-400 status-icon"></i>';
                } else {
                    statusIcon = '<i class="fas fa-check text-gray-400 status-icon"></i>';
                }
                
                statusDiv.innerHTML = statusIcon;
                footerDiv.appendChild(statusDiv);
            }
            
            messageDiv.appendChild(footerDiv);
            
            return messageDiv;
        }
        
        // Función para obtener ícono según tipo de archivo
        function getFileIconClass(filename) {
            const ext = filename.split('.').pop().toLowerCase();
            
            if (['pdf'].includes(ext)) return 'fas fa-file-pdf text-red-500';
            if (['doc', 'docx'].includes(ext)) return 'fas fa-file-word text-blue-500';
            if (['xls', 'xlsx'].includes(ext)) return 'fas fa-file-excel text-green-500';
            if (['ppt', 'pptx'].includes(ext)) return 'fas fa-file-powerpoint text-orange-500';
            if (['zip', 'rar', '7z'].includes(ext)) return 'fas fa-file-archive text-purple-500';
            if (['txt'].includes(ext)) return 'fas fa-file-alt text-gray-500';
            
            return 'fas fa-file text-gray-500';
        }
        
        // Función para formatear mensaje con emojis
        function formatMessageWithEmojis(message) {
            // Aquí puedes implementar una lógica para transformar códigos de emoji a imágenes
            // Por simplicidad, solo devolvemos el mensaje
            return message;
        }
        
        // Función mejorada para mostrar imagen en modal
        function showImageModal(url) {
            console.log('Mostrando modal de imagen para:', url);
            const modal = document.getElementById('image-modal');
            const modalImage = document.getElementById('modal-image');
            
            // Asegurarse que la imagen sea válida antes de mostrar el modal
            if (!url) {
                console.error('URL de imagen no válida');
                return;
            }
            
            // Precargar la imagen
            const img = new Image();
            img.onload = function() {
                // Una vez cargada, mostrar el modal
                console.log('Imagen cargada correctamente, mostrando modal');
                modalImage.src = url;
                modal.classList.add('active');
                modal.style.display = 'flex';
                modal.style.visibility = 'visible';
                modal.style.opacity = '1';
            };
            img.onerror = function() {
                console.error('Error al cargar la imagen:', url);
                alert('No se pudo cargar la imagen');
            };
            img.src = url;
        }
        
        // Función para mostrar mensajes en el chat
        function displayMessages(messages) {
            const chatMessages = document.getElementById('chat-messages');
            chatMessages.innerHTML = '';
            
            let unreadMessageIds = [];
            
            messages.forEach(message => {
                const isOutgoing = message.sender_id == currentUser.id;
                const messageElement = createMessageElement(message, isOutgoing);
                chatMessages.appendChild(messageElement);
                
                // Recolectar IDs de mensajes no leídos que son del otro usuario
                if (!isOutgoing && !message.read) {
                    unreadMessageIds.push(message.id);
                }
            });
            
            // Marcar mensajes como leídos
            if (unreadMessageIds.length > 0 && isConnected) {
                socket.send(JSON.stringify({
                    type: 'read',
                    message_ids: unreadMessageIds,
                    sender_id: otherUser.id
                }));
            }
            
            // Scroll al final
            scrollToBottom();
        }
        
        // Función para agregar un nuevo mensaje al chat
        function addMessage(message, isOutgoing) {
            const chatMessages = document.getElementById('chat-messages');
            const messageElement = createMessageElement(message, isOutgoing);
            chatMessages.appendChild(messageElement);
            
            // Si es un mensaje entrante, marcarlo como leído
            if (!isOutgoing && !message.read && isConnected) {
                socket.send(JSON.stringify({
                    type: 'read',
                    message_ids: [message.id],
                    sender_id: otherUser.id
                }));
            }
            
            // Scroll al final
            scrollToBottom();
        }
        
        // Función para hacer scroll al final del chat
        function scrollToBottom() {
            const chatMessages = document.getElementById('chat-messages');
            chatMessages.scrollTop = chatMessages.scrollHeight;
        }
        
        // Función para enviar mensaje de texto
        function sendTextMessage() {
            const messageInput = document.getElementById('message-input');
            const message = messageInput.value.trim();
            
            if (!message || !isConnected) return;
            
            // Limpiar campo
            messageInput.value = '';
            
            // ID temporal para actualización posterior
            const tempId = 'temp-' + Date.now();
            
            // Enviar mensaje al servidor
            socket.send(JSON.stringify({
                type: 'message',
                temp_id: tempId,
                sender_id: currentUser.id,
                receiver_id: otherUser.id,
                message: message,
                message_type: 'text'
            }));
            
            // Mostrar mensaje en el chat (optimista)
            const optimisticMessage = {
                id: tempId,
                sender_id: currentUser.id,
                receiver_id: otherUser.id,
                message: message,
                type: 'text',
                timestamp: new Date().toISOString(),
                read: 0,
                delivered: 0
            };
            
            addMessage(optimisticMessage, true);
        }
        
        // Función para enviar archivo
        function sendFile(file, messageText = '') {
            if (!file || !isConnected) return;
            
            // Verificar tamaño
            if (file.size > 20 * 1024 * 1024) { // 20 MB
                alert('El archivo es demasiado grande. El tamaño máximo es 20 MB.');
                return;
            }
            
            // Crear FormData
            const formData = new FormData();
            formData.append('file', file);
            formData.append('receiver_id', otherUser.id);
            if (messageText) formData.append('message', messageText);
            
            // Enviar archivo al servidor
            fetch('upload_handler.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    console.log('Archivo enviado:', data);
                    
                    // Crear mensaje optimista
                    const optimisticMessage = {
                        id: data.message_id,
                        sender_id: currentUser.id,
                        receiver_id: otherUser.id,
                        message: messageText,
                        type: data.type,
                        file_url: data.file.url,
                        file_name: data.file.name,
                        file_size: data.file.size,
                        file_type: data.file.type,
                        timestamp: new Date().toISOString(),
                        read: 0,
                        delivered: 0
                    };
                    
                    addMessage(optimisticMessage, true);
                } else {
                    console.error('Error al enviar archivo:', data.error);
                    alert('Error al enviar archivo: ' + data.error);
                }
            })
            .catch(error => {
                console.error('Error en la solicitud:', error);
                alert('Error al enviar archivo');
            });
        }
        
        // Función para manejar evento "typing"
        function handleTyping() {
            // Limpiar timeout anterior
            if (typingTimeout) {
                clearTimeout(typingTimeout);
            }
            
            // Enviar "typing" al servidor
            if (isConnected) {
                socket.send(JSON.stringify({
                    type: 'typing',
                    sender_id: currentUser.id,
                    receiver_id: otherUser.id,
                    typing: true
                }));
            }
            
            // Establecer timeout para enviar "stopped typing"
            typingTimeout = setTimeout(() => {
                if (isConnected) {
                    socket.send(JSON.stringify({
                        type: 'typing',
                        sender_id: currentUser.id,
                        receiver_id: otherUser.id,
                        typing: false
                    }));
                }
            }, 1000);
        }
        
        // Función para mostrar/ocultar indicador de escritura
        function showTypingIndicator(show) {
            document.getElementById('typing-indicator').classList.toggle('hidden', !show);
        }
        
        // Función para actualizar indicador de estado de usuario
        function updateUserStatus(status) {
            otherUser.status = status;
            const statusText = document.getElementById('status-text');
            
            if (status === 'online') {
                statusText.textContent = 'En línea';
            } else if (status === 'away') {
                statusText.textContent = 'Ausente';
            } else {
                statusText.textContent = 'Desconectado';
            }
        }
        
        // Función para actualizar estado de lectura de mensajes
        function updateMessageReadStatus(messageIds) {
            messageIds.forEach(id => {
                const messageElement = document.querySelector(`[data-message-id="${id}"]`);
                if (messageElement) {
                    const statusElement = messageElement.querySelector('.message-status');
                    if (statusElement) {
                        statusElement.innerHTML = '<i class="fas fa-check-double text-blue-500 status-icon"></i>';
                    }
                }
            });
        }
        
        // Función mejorada para iniciar una llamada
        function startCall(callType) {
            if (!isConnected) {
                alert('No hay conexión con el servidor');
                return;
            }
            
            // Mostrar confirmación primero
            if (!confirm(`¿Iniciar llamada ${callType === 'video' ? 'de video' : 'de voz'} con ${otherUser.name}? El navegador pedirá permiso para acceder a tu ${callType === 'video' ? 'cámara y micrófono' : 'micrófono'}.`)) {
                return;
            }
            
            // Mostrar UI de llamada saliente primero, antes de pedir permisos
            const callContainer = document.getElementById('call-container');
            callContainer.style.display = 'flex';
            callContainer.classList.add('active');
            document.getElementById('incoming-call').classList.add('hidden');
            document.getElementById('ongoing-call').classList.add('hidden');
            document.getElementById('outgoing-call').classList.remove('hidden');
            document.getElementById('outgoing-status-text').textContent = 'Iniciando llamada...';
            
            const constraints = {
                audio: true,
                video: callType === 'video'
            };
            
            // Función para manejar el caso donde no hay permisos pero la llamada continúa
            const proceedWithoutMedia = () => {
                console.log('Procediendo con llamada sin acceso a multimedia');
                
                // Enviar solicitud de llamada igual, pero indicando limitaciones
                socket.send(JSON.stringify({
                    type: 'call_request',
                    receiver_id: otherUser.id,
                    call_type: callType,
                    no_media: true
                }));
                
                // Actualizar estado
                document.getElementById('outgoing-status-text').textContent = 'Llamando... (sin acceso a multimedia)';
            };
            
            navigator.mediaDevices.getUserMedia(constraints)
                .then(stream => {
                    localStream = stream;
                    
                    // Mostrar video local si es una llamada de video
                    const localVideo = document.getElementById('local-video');
                    if (callType === 'video') {
                        localVideo.srcObject = stream;
                        localVideo.classList.remove('hidden');
                    } else {
                        localVideo.srcObject = null;
                        localVideo.classList.add('hidden');
                    }
                    
                    // Enviar solicitud de llamada
                    socket.send(JSON.stringify({
                        type: 'call_request',
                        receiver_id: otherUser.id,
                        call_type: callType
                    }));
                    
                    // Actualizar estado
                    document.getElementById('outgoing-status-text').textContent = 'Llamando...';
                })
                .catch(error => {
                    console.error('Error al acceder a la cámara/micrófono:', error);
                    
                    // Determinar el tipo específico de error
                    if (error.name === 'NotAllowedError') {
                        // Usuario rechazó permisos explícitamente
                        if (confirm('Has rechazado el acceso al micrófono. ¿Quieres intentar continuar la llamada sin audio (solo mensajes)?')) {
                            proceedWithoutMedia();
                        } else {
                            hideCallUI();
                        }
                    } else if (error.name === 'NotFoundError') {
                        // No se encontró dispositivo 
                        if (confirm('No se encontró un micrófono en tu dispositivo. ¿Quieres intentar continuar la llamada sin audio (solo mensajes)?')) {
                            proceedWithoutMedia();
                        } else {
                            hideCallUI();
                        }
                    } else {
                        // Otros errores
                        if (confirm('Hubo un problema al acceder al micrófono (' + error.message + '). ¿Quieres intentar continuar la llamada de forma limitada?')) {
                            proceedWithoutMedia();
                        } else {
                            hideCallUI();
                        }
                    }
                });
        }
        
        // Función para manejar llamadas entrantes (incluyendo modo sin medios)
        function handleIncomingCall(callId, callType, noMedia = false) {
            const acceptCall = () => {
                if (noMedia) {
                    // Si la llamada original no tiene medios, no intentamos acceder
                    setupTextOnlyCall(callId, callType);
                    return;
                }
                
                const constraints = {
                    audio: true,
                    video: callType === 'video'
                };
                
                navigator.mediaDevices.getUserMedia(constraints)
                    .then(stream => {
                        localStream = stream;
                        
                        // Mostrar video local
                        const localVideo = document.getElementById('local-video');
                        if (callType === 'video') {
                            localVideo.srcObject = stream;
                            localVideo.classList.remove('hidden');
                        } else {
                            localVideo.srcObject = null;
                            localVideo.classList.add('hidden');
                        }
                        
                        // Configurar conexión
                        setupPeerConnection(false, callId, callType);
                        
                        // Responder a la llamada
                        socket.send(JSON.stringify({
                            type: 'call_response',
                            call_id: callId,
                            response: 'accept'
                        }));
                        
                        // Mostrar UI de llamada en curso
                        document.getElementById('incoming-call').classList.add('hidden');
                        document.getElementById('outgoing-call').classList.add('hidden');
                        document.getElementById('ongoing-call').classList.remove('hidden');
                    })
                    .catch(error => {
                        console.error('Error al acceder a la cámara/micrófono:', error);
                        
                        // Preguntar si quiere aceptar en modo texto
                        if (confirm('No se pudo acceder al micrófono. ¿Quieres aceptar la llamada en modo texto solamente?')) {
                            setupTextOnlyCall(callId, callType);
                        } else {
                            // Rechazar llamada
                            socket.send(JSON.stringify({
                                type: 'call_response',
                                call_id: callId,
                                response: 'reject',
                                reason: 'media_error'
                            }));
                            
                            hideCallUI();
                        }
                    });
            };
            
            // Función para manejar llamadas solo texto
            function setupTextOnlyCall(callId, callType) {
                // Responder a la llamada indicando limitaciones
                socket.send(JSON.stringify({
                    type: 'call_response',
                    call_id: callId,
                    response: 'accept',
                    text_only: true
                }));
                
                // Configurar UI especial para llamada de solo texto
                document.getElementById('incoming-call').classList.add('hidden');
                document.getElementById('outgoing-call').classList.add('hidden');
                document.getElementById('ongoing-call').classList.remove('hidden');
                
                // Mostrar UI adaptada para llamada sin medios
                document.getElementById('remote-video').style.display = 'none';
                document.getElementById('local-video').style.display = 'none';
                
                // Crear un contenedor de texto específico
                const videoContainer = document.querySelector('.call-video-container');
                if (videoContainer) {
                    const textContainer = document.createElement('div');
                    textContainer.className = 'text-center p-4 bg-gray-800 rounded-lg';
                    textContainer.innerHTML = '<p class="text-white mb-4">Llamada en modo texto</p>' +
                                         '<div class="text-sm text-gray-300">No hay audio ni video disponible</div>';
                    videoContainer.appendChild(textContainer);
                }
                
                // Guardar llamada
                currentCall = {
                    id: callId,
                    type: 'text_only',
                    status: 'ongoing'
                };
            }
            
            const rejectCall = () => {
                socket.send(JSON.stringify({
                    type: 'call_response',
                    call_id: callId,
                    response: 'reject'
                }));
                
                hideCallUI();
            };
            
            // Mostrar UI de llamada entrante
            const callContainer = document.getElementById('call-container');
            callContainer.classList.add('active');
            callContainer.style.display = 'flex';
            document.getElementById('outgoing-call').classList.add('hidden');
            document.getElementById('ongoing-call').classList.add('hidden');
            document.getElementById('incoming-call').classList.remove('hidden');
            
            // Actualizar texto
            document.getElementById('call-status-text').textContent = 
                `Llamada ${callType === 'video' ? 'de video' : ''} entrante...` +
                (noMedia ? ' (sin audio/video)' : '');
            
            // Configurar botones
            document.getElementById('accept-call').onclick = acceptCall;
            document.getElementById('reject-call').onclick = rejectCall;
            
            // Reproducir sonido de llamada (opcional)
            // playRingtone();
        }
        
        function setupPeerConnection(isInitiator, callId, callType) {
            // Crear conexión peer
            peerConnection = new RTCPeerConnection(rtcConfig);
            
            // Agregar pistas locales
            if (localStream) {
                localStream.getTracks().forEach(track => {
                    peerConnection.addTrack(track, localStream);
                });
            }
            
            // Escuchar eventos ICE
            peerConnection.onicecandidate = event => {
                if (event.candidate) {
                    socket.send(JSON.stringify({
                        type: 'webrtc_ice',
                        call_id: callId,
                        candidate: event.candidate,
                        receiver_id: otherUser.id
                    }));
                }
            };
            
            // Escuchar pistas remotas
            peerConnection.ontrack = event => {
                const remoteVideo = document.getElementById('remote-video');
                if (remoteVideo.srcObject !== event.streams[0]) {
                    remoteVideo.srcObject = event.streams[0];
                }
            };
            
            // Si es quien inicia la llamada, crear oferta
            if (isInitiator) {
                peerConnection.createOffer()
                    .then(offer => peerConnection.setLocalDescription(offer))
                    .then(() => {
                        socket.send(JSON.stringify({
                            type: 'webrtc_offer',
                            call_id: callId,
                            sdp: peerConnection.localDescription,
                            receiver_id: otherUser.id
                        }));
                    })
                    .catch(error => console.error('Error al crear oferta:', error));
            }
            
            // Guardar información de llamada
            currentCall = {
                id: callId,
                type: callType,
                status: 'connecting',
                peer: peerConnection
            };
        }
        
        function endCurrentCall() {
            if (currentCall) {
                socket.send(JSON.stringify({
                    type: 'call_end',
                    call_id: currentCall.id
                }));
                
                // Cerrar conexión
                if (currentCall.peer) {
                    currentCall.peer.close();
                }
                
                // Detener streams
                if (localStream) {
                    localStream.getTracks().forEach(track => track.stop());
                    localStream = null;
                }
                
                currentCall = null;
            }
            
            hideCallUI();
        }
        
        function hideCallUI() {
            console.log('Ocultando UI de llamada');
            const callContainer = document.getElementById('call-container');
            callContainer.classList.remove('active');
            callContainer.style.display = 'none';
            
            // Detener streams
            if (localStream) {
                localStream.getTracks().forEach(track => track.stop());
                localStream = null;
            }
            
            // Limpiar videos
            document.getElementById('remote-video').srcObject = null;
            document.getElementById('local-video').srcObject = null;
        }
        
        function toggleMicrophone() {
            if (localStream) {
                const audioTracks = localStream.getAudioTracks();
                if (audioTracks.length > 0) {
                    isAudioEnabled = !isAudioEnabled;
                    audioTracks[0].enabled = isAudioEnabled;
                    
                    // Actualizar UI
                    const micButton = document.getElementById('toggle-mic');
                    const micIcon = micButton.querySelector('i');
                    
                    if (isAudioEnabled) {
                        micIcon.className = 'fas fa-microphone fa-lg';
                        micButton.classList.remove('bg-red-500');
                        micButton.classList.add('bg-gray-700');
                    } else {
                        micIcon.className = 'fas fa-microphone-slash fa-lg';
                        micButton.classList.remove('bg-gray-700');
                        micButton.classList.add('bg-red-500');
                    }
                }
            }
        }
        
        function toggleVideo() {
            if (localStream) {
                const videoTracks = localStream.getVideoTracks();
                if (videoTracks.length > 0) {
                    isVideoEnabled = !isVideoEnabled;
                    videoTracks[0].enabled = isVideoEnabled;
                    
                    // Actualizar UI
                    const videoButton = document.getElementById('toggle-video');
                    const videoIcon = videoButton.querySelector('i');
                    
                    if (isVideoEnabled) {
                        videoIcon.className = 'fas fa-video fa-lg';
                        videoButton.classList.remove('bg-red-500');
                        videoButton.classList.add('bg-blue-500');
                    } else {
                        videoIcon.className = 'fas fa-video-slash fa-lg';
                        videoButton.classList.remove('bg-blue-500');
                        videoButton.classList.add('bg-red-500');
                    }
                }
            }
        }
        
        // Función para enviar latido (heartbeat)
        function sendHeartbeat() {
            if (isConnected) {
                socket.send(JSON.stringify({
                    type: 'heartbeat',
                    user_id: currentUser.id
                }));
            }
        }
        
        // Función para conectar WebSocket
        function connectWebSocket() {
            // Crear conexión WebSocket
            socket = new WebSocket(WEBSOCKET_URL);
            
            socket.onopen = function(e) {
                console.log("Conexión WebSocket establecida a", WEBSOCKET_URL);
                isConnected = true;
                reconnectAttempts = 0;
                
                // Autenticar conexión
                socket.send(JSON.stringify({
                    type: 'auth',
                    user_id: currentUser.id
                }));
                
                // Configurar heartbeat cada 30 segundos
                heartbeatInterval = setInterval(sendHeartbeat, 30000);
            };
            
            socket.onmessage = function(event) {
                const data = JSON.parse(event.data);
                
                switch(data.type) {
                    case 'auth_success':
                        console.log('Autenticación exitosa');
                        // Actualizar lista de usuarios en línea
                        if (data.online_users) {
                            data.online_users.forEach(user => {
                                if (user.user_id === otherUser.id) {
                                    updateUserStatus(user.status);
                                }
                            });
                        }
                        break;
                        
                    case 'message':
                        // Mensaje recibido
                        if (data.sender_id == otherUser.id) {
                            const messageObj = {
                                id: data.message_id,
                                sender_id: data.sender_id,
                                receiver_id: currentUser.id,
                                message: data.message,
                                type: data.message_type || 'text',
                                file_url: data.file_url,
                                file_name: data.file_name,
                                file_size: data.file_size,
                                file_type: data.file_type,
                                timestamp: data.timestamp,
                                read: 0,
                                delivered: 1
                            };
                            
                            addMessage(messageObj, false);
                        }
                        break;
                        
                    case 'typing':
                        // Indicador de escritura
                        if (data.sender_id == otherUser.id) {
                            showTypingIndicator(data.typing);
                        }
                        break;
                        
                    case 'sent':
                        // Confirmación de mensaje enviado
                        // Actualizar ID de mensaje temporal
                        const tempMsg = document.querySelector(`[data-message-id="${data.temp_id}"]`);
                        if (tempMsg) {
                            tempMsg.setAttribute('data-message-id', data.message_id);
                            
                            // Actualizar estado de entrega
                            const statusElement = tempMsg.querySelector('.message-status');
                            if (statusElement) {
                                const iconClass = data.delivered ? 'fa-check-double' : 'fa-check';
                                statusElement.innerHTML = `<i class="fas ${iconClass} text-gray-400 status-icon"></i>`;
                            }
                        }
                        break;
                        
                    case 'read':
                        // Confirmación de lectura
                        if (data.reader_id == otherUser.id) {
                            updateMessageReadStatus(data.message_ids);
                        }
                        break;
                        
                    case 'user_status':
                        // Actualización de estado de usuario
                        if (data.user_id == otherUser.id) {
                            updateUserStatus(data.status);
                        }
                        break;
                        
                    case 'call_incoming':
                        // Llamada entrante
                        if (data.caller_id == otherUser.id) {
                            handleIncomingCall(data.call_id, data.call_type, data.no_media);
                        }
                        break;
                        
                    case 'call_initiated':
                        // Confirmación de llamada iniciada
                        if (data.receiver_id == otherUser.id) {
                            if (!data.receiver_available) {
                                document.getElementById('outgoing-status-text').textContent = 
                                    'El usuario no está disponible';
                                
                                setTimeout(() => {
                                    hideCallUI();
                                }, 3000);
                            } else {
                                // Configurar conexión peer
                                setupPeerConnection(true, data.call_id, data.call_type);
                            }
                        }
                        break;
                        
                    case 'call_response':
                        // Respuesta a llamada
                        if (currentCall && data.call_id == currentCall.id) {
                            if (data.response === 'accept') {
                                document.getElementById('outgoing-call').classList.add('hidden');
                                document.getElementById('ongoing-call').classList.remove('hidden');
                                currentCall.status = 'ongoing';
                            } else {
                                document.getElementById('outgoing-status-text').textContent = 
                                    'Llamada rechazada';
                                
                                setTimeout(() => {
                                    hideCallUI();
                                    
                                    // Detener streams
                                    if (localStream) {
                                        localStream.getTracks().forEach(track => track.stop());
                                        localStream = null;
                                    }
                                    
                                    currentCall = null;
                                }, 2000);
                            }
                        }
                        break;
                        
                    case 'webrtc_offer':
                        // Oferta WebRTC
                        if (currentCall && data.call_id == currentCall.id && peerConnection) {
                            peerConnection.setRemoteDescription(new RTCSessionDescription(data.sdp))
                                .then(() => peerConnection.createAnswer())
                                .then(answer => peerConnection.setLocalDescription(answer))
                                .then(() => {
                                    socket.send(JSON.stringify({
                                        type: 'webrtc_answer',
                                        call_id: data.call_id,
                                        sdp: peerConnection.localDescription,
                                        receiver_id: otherUser.id
                                    }));
                                })
                                .catch(error => console.error('Error al crear respuesta:', error));
                        }
                        break;
                        
                    case 'webrtc_answer':
                        // Respuesta WebRTC
                        if (currentCall && data.call_id == currentCall.id && peerConnection) {
                            peerConnection.setRemoteDescription(new RTCSessionDescription(data.sdp))
                                .catch(error => console.error('Error al establecer descripción remota:', error));
                        }
                        break;
                        
                    case 'webrtc_ice':
                        // Candidato ICE
                        if (currentCall && data.call_id == currentCall.id && peerConnection) {
                            peerConnection.addIceCandidate(new RTCIceCandidate(data.candidate))
                                .catch(error => console.error('Error al agregar candidato ICE:', error));
                        }
                        break;
                        
                    case 'call_ended':
                        // Llamada finalizada
                        if (currentCall && data.call_id == currentCall.id) {
                            document.getElementById('call-status-text').textContent = 
                                'Llamada finalizada';
                            
                            setTimeout(() => {
                                hideCallUI();
                                
                                // Detener streams
                                if (localStream) {
                                    localStream.getTracks().forEach(track => track.stop());
                                    localStream = null;
                                }
                                
                                // Cerrar conexión peer
                                if (peerConnection) {
                                    peerConnection.close();
                                    peerConnection = null;
                                }
                                
                                currentCall = null;
                            }, 1000);
                        }
                        break;
                }
            };
            
            socket.onclose = function(event) {
                isConnected = false;
                clearInterval(heartbeatInterval);
                
                // Actualizar estado
                document.getElementById('status-text').textContent = 'Desconectado';
                
                // Intentar reconectar
                if (reconnectAttempts < MAX_RECONNECT_ATTEMPTS) {
                    reconnectAttempts++;
                    console.log(`Intento de reconexión ${reconnectAttempts} de ${MAX_RECONNECT_ATTEMPTS}`);
                    setTimeout(connectWebSocket, 3000);
                } else {
                    alert("Se perdió la conexión con el servidor. Por favor, recarga la página.");
                }
            };
            
            socket.onerror = function(error) {
                console.error("Error WebSocket:", error);
            };
        }
        
        // Inicialización al cargar la página
        document.addEventListener('DOMContentLoaded', function() {
            console.log('DOM cargado, inicializando chat...');
            
            // Mostrar mensajes iniciales
            displayMessages(initialMessages);
            
            // Inicializar selector de emojis
            const pickerOptions = {
                onEmojiSelect: emoji => {
                    const messageInput = document.getElementById('message-input');
                    messageInput.value += emoji.native;
                    messageInput.focus();
                }
            };
            
            // Configurar emoji picker mejorado
            const emojiBtn = document.getElementById('emoji-btn');
            const emojiPickerContainer = document.getElementById('emoji-picker-container');
            
            emojiBtn.addEventListener('click', (e) => {
                e.stopPropagation(); // Prevenir propagación
                
                if (emojiPickerContainer.classList.contains('hidden')) {
                    console.log('Mostrando emoji picker');
                    emojiPickerContainer.classList.remove('hidden');
                    
                    // Crear picker si no existe
                    if (!emojiPickerContainer.hasChildNodes()) {
                        const picker = new EmojiMart.Picker(pickerOptions);
                        emojiPickerContainer.appendChild(picker);
                        
                        // Ajustar posición después de renderizar
                        setTimeout(() => {
                            const pickerElement = emojiPickerContainer.querySelector('.emoji-mart');
                            if (pickerElement) {
                                // Asegurar que esté dentro de la ventana visible
                                const rect = pickerElement.getBoundingClientRect();
                                if (rect.bottom > window.innerHeight) {
                                    pickerElement.style.bottom = '80px';
                                    pickerElement.style.top = 'auto';
                                }
                            }
                        }, 100);
                    }
                } else {
                    console.log('Ocultando emoji picker');
                    emojiPickerContainer.classList.add('hidden');
                }
            });
            
            // Cerrar picker al hacer clic fuera
            document.addEventListener('click', (e) => {
                if (!emojiPickerContainer.contains(e.target) && !emojiBtn.contains(e.target) && !emojiPickerContainer.classList.contains('hidden')) {
                    emojiPickerContainer.classList.add('hidden');
                }
            });
            
            // Arreglar el menú lateral
            document.getElementById('menu-btn').addEventListener('click', function(e) {
                e.preventDefault();
                console.log('Abriendo menú lateral');
                const sideMenu = document.getElementById('side-menu');
                sideMenu.classList.remove('hidden');
                
                // Asegurar que el overlay del menú funcione correctamente
                const menuOverlay = document.getElementById('menu-overlay');
                if (menuOverlay) {
                    menuOverlay.addEventListener('click', function() {
                        console.log('Cerrando menú lateral (click en overlay)');
                        sideMenu.classList.add('hidden');
                    });
                }
                
                // También permitir cerrar con Escape
                const handleEscapeMenuClose = function(event) {
                    if (event.key === 'Escape' && !sideMenu.classList.contains('hidden')) {
                        console.log('Cerrando menú lateral (Escape)');
                        sideMenu.classList.add('hidden');
                        document.removeEventListener('keydown', handleEscapeMenuClose);
                    }
                };
                
                document.addEventListener('keydown', handleEscapeMenuClose);
            });
            
            // Asegurarnos de que el botón de cerrar en el menú funcione
            const closeMenuBtns = document.querySelectorAll('#side-menu a, #side-menu button');
            closeMenuBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    console.log('Cerrando menú lateral (botón interno)');
                    document.getElementById('side-menu').classList.add('hidden');
                });
            });
            
            // Agregar evento para cerrar modal de imagen al hacer clic
            const imageModal = document.getElementById('image-modal');
            imageModal.addEventListener('click', function(e) {
                // Cerrar solo si se hace clic fuera de la imagen
                if (e.target === imageModal) {
                    imageModal.classList.remove('active');
                    imageModal.style.display = 'none';
                    console.log('Modal de imagen cerrado por clic');
                }
            });
            
            // Evento para cerrar con Escape
            document.addEventListener('keydown', function(e) {
                if (e.key === 'Escape') {
                    console.log('Tecla Escape presionada, cerrando modales');
                    const imageModal = document.getElementById('image-modal');
                    imageModal.classList.remove('active');
                    imageModal.style.display = 'none';
                    
                    // No ocultar el contenedor de llamadas si hay una llamada activa
                    if (!currentCall) {
                        const callContainer = document.getElementById('call-container');
                        callContainer.classList.remove('active');
                        callContainer.style.display = 'none';
                    }
                    
                    // Cerrar menú lateral si está abierto
                    const sideMenu = document.getElementById('side-menu');
                    if (!sideMenu.classList.contains('hidden')) {
                        sideMenu.classList.add('hidden');
                    }
                }
            });
            
            // Configurar evento de envío de mensaje
            document.getElementById('send-btn').addEventListener('click', sendTextMessage);
            document.getElementById('message-input').addEventListener('keydown', function(e) {
                if (e.key === 'Enter' && !e.shiftKey) {
                    e.preventDefault();
                    sendTextMessage();
                }
            });
            
            // Configurar evento de escritura
            document.getElementById('message-input').addEventListener('input', handleTyping);
            
            // Configurar selector de archivos
            document.getElementById('file-input').addEventListener('change', function(e) {
                const file = e.target.files[0];
                if (file) {
                    // Preguntar por mensaje opcional
                    const message = prompt('Mensaje opcional para el archivo:', '');
                    sendFile(file, message);
                    // Limpiar input
                    e.target.value = '';
                }
            });
            
            // Configurar botones de llamada
            document.getElementById('audio-call-btn').addEventListener('click', () => startCall('audio'));
            document.getElementById('video-call-btn').addEventListener('click', () => startCall('video'));
            document.getElementById('cancel-call').addEventListener('click', endCurrentCall);
            document.getElementById('end-call').addEventListener('click', endCurrentCall);
            document.getElementById('toggle-mic').addEventListener('click', toggleMicrophone);
            document.getElementById('toggle-video').addEventListener('click', toggleVideo);
            
            // Conectar WebSocket
            connectWebSocket();
            
            console.log('Inicialización completa');
        });
        
        // También agregar evento de carga de ventana para asegurar que los modales estén ocultos
        window.addEventListener('load', function() {
            console.log('Ventana completamente cargada');
            
            // Script para forzar ocultar todos los elementos modales
            const imageModal = document.getElementById('image-modal');
            imageModal.style.display = 'none';
            imageModal.style.visibility = 'hidden';
            imageModal.style.opacity = '0';
            
            const callContainer = document.getElementById('call-container');
            callContainer.style.display = 'none';
            callContainer.style.visibility = 'hidden';
            callContainer.style.opacity = '0';
            
            // También verificar si hay algún elemento superpuesto inesperado
            setTimeout(() => {
                console.log('Verificando elementos superpuestos...');
                const allElements = document.querySelectorAll('*');
                for (let i = 0; i < allElements.length; i++) {
                    const el = allElements[i];
                    const style = window.getComputedStyle(el);
                    
                    if (style.position === 'fixed' && 
                        style.zIndex > 50 && 
                        style.display !== 'none' &&
                        el.id !== 'typing-indicator') {
                        console.log('Elemento superpuesto detectado:', el.id || 'sin-id', style.zIndex, style.display);
                        // Forzar ocultar
                        el.style.display = 'none !important';
                        el.style.visibility = 'hidden !important';
                        el.style.opacity = '0 !important';
                    }
                }
            }, 1000);
        });
        
        // Manejar cierre de ventana
        window.addEventListener('beforeunload', function() {
            if (socket && socket.readyState === WebSocket.OPEN) {
                socket.close();
            }
            
            // Detener streams
            if (localStream) {
                localStream.getTracks().forEach(track => track.stop());
            }
        });
    </script>
    
    <!-- Script de emergencia para ocultar modales -->
    <script>
    // Este script se ejecuta inmediatamente y es la primera línea de defensa
    (function() {
        console.log('Script de emergencia ejecutándose');
        
        // Función para ocultar elementos con position:fixed
        function hideFixedElements() {
            var elements = document.querySelectorAll('*');
            for (var i = 0; i < elements.length; i++) {
                var style = window.getComputedStyle(elements[i]);
                if (style.position === 'fixed' && 
                    (style.zIndex > 50 || style.backgroundColor.includes('rgba'))) {
                    console.log('Ocultando elemento fijo:', elements[i].id || 'elemento sin id');
                    elements[i].style.display = 'none';
                    elements[i].style.visibility = 'hidden';
                }
            }
        }
        
        // Ejecutar inmediatamente y en varios momentos
        hideFixedElements();
        setTimeout(hideFixedElements, 100);
        setTimeout(hideFixedElements, 500);
        setTimeout(hideFixedElements, 1000);
        
        // También agregar al evento DOMContentLoaded
        document.addEventListener('DOMContentLoaded', hideFixedElements);
        window.addEventListener('load', hideFixedElements);
    })();
    </script>
</body>
</html>